"""
Package that contains the water tank example
"""
from cmt.bmi.examples.water_tank.rainfall import Rainfall, InputFile
from cmt.bmi.examples.water_tank.water_tank import WaterTank
from cmt.bmi.examples.water_tank.rainfall import Error as RainfallError
from cmt.bmi.examples.water_tank.water_tank import Error as WaterTankError
#import cmt.bmi.examples.water_tank.rain_in_tank
